@@ -1,14 +1,24 @@
 # -*- coding: utf-8 -*-
-from allianceauth import hooks
-from allianceauth.services.hooks import MenuItemHook, UrlHook
+
+"""
+auth hooks
+"""
 
 from django.utils.translation import ugettext_lazy as _
 
+from allianceauth import hooks
+from allianceauth.services.hooks import MenuItemHook, UrlHook
+
 from . import urls
 
 
 @hooks.register("menu_item_hook")
 def register_menu():
+    """
+    register our menu
+    :return:
+    """
+
     return MenuItemHook(
         _("Fleet Activity Tracking"),
         "fas fa-crosshairs fa-fw",
@@ -19,4 +29,9 @@ def register_menu():
 
 @hooks.register("url_hook")
 def register_url():
+    """
+    register our menu link
+    :return:
+    """
+
     return UrlHook(urls, "imicusfat", r"^imicusfat/")
