@@ -1,4 +1,9 @@
 # -*- coding: utf-8 -*-
+
+"""
+providers
+"""
+
 from esi.clients import EsiClientProvider
 
 from allianceauth.services.hooks import get_extension_logger
