@@ -1,13 +1,21 @@
+# coding=utf-8
+
+"""
+url configuration
+"""
+
 from django.conf.urls import url
 
 from . import views
 
-
-app_name = "imicusfat"
+app_name: str = "imicusfat"
 
 urlpatterns = [
     url(r"^$", views.imicusfat_view, name="imicusfat_view"),
+    # stats main page
     url(r"^stats/$", views.stats, name="stats"),
+    url(r"^stats/(?P<year>[0-9]+)/$", views.stats, name="stats"),
+    # stats corp
     url(r"^stats/corp/$", views.stats_corp, name="stats_corp"),
     url(r"^stats/corp/(?P<corpid>[0-9]+)/$", views.stats_corp, name="stats_corp"),
     url(
@@ -15,6 +23,7 @@ urlpatterns = [
         views.stats_corp,
         name="stats_corp",
     ),
+    # stats char
     url(r"^stats/char/$", views.stats_char, name="stats_char"),
     url(r"^stats/char/(?P<charid>[0-9]+)/$", views.stats_char, name="stats_char"),
     url(
@@ -22,6 +31,7 @@ urlpatterns = [
         views.stats_char,
         name="stats_char",
     ),
+    # stats alliance
     url(r"^stats/ally/$", views.stats_alliance, name="stats_ally"),
     url(
         r"^stats/ally/(?P<allianceid>[0-9]+)/$", views.stats_alliance, name="stats_ally"
@@ -31,6 +41,7 @@ urlpatterns = [
         views.stats_alliance,
         name="stats_ally",
     ),
+    # fat links
     url(r"^links/$", views.links, name="links"),
     url(
         r"^links/create/esi/(?P<hash>[a-zA-Z0-9]+)/$",
