@@ -1,13 +1,10 @@
 # -*- coding: utf-8 -*-
-from allianceauth.authentication.decorators import permissions_required
-from allianceauth.authentication.models import CharacterOwnership
-from allianceauth.eveonline.models import (
-    EveAllianceInfo,
-    EveCharacter,
-    EveCorporationInfo,
-)
-from allianceauth.eveonline.providers import provider
-from allianceauth.services.hooks import get_extension_logger
+
+"""
+the views
+"""
+
+import random
 
 from collections import OrderedDict
 
@@ -22,15 +19,24 @@ from django.utils.crypto import get_random_string
 from esi.decorators import token_required
 from esi.models import Token
 
+from allianceauth.authentication.decorators import permissions_required
+from allianceauth.authentication.models import CharacterOwnership
+from allianceauth.eveonline.models import (
+    EveAllianceInfo,
+    EveCharacter,
+    EveCorporationInfo,
+)
+from allianceauth.eveonline.providers import provider
+from allianceauth.services.hooks import get_extension_logger
+
 from . import __title__
-from .forms import FatLinkForm, ManualFatForm, ClickFatForm
+from .forms import FatLinkForm, ManualFatForm, ClickFatForm, FatLinkEditForm
 from .models import IFat, ClickIFatDuration, IFatLink, ManualIFat, DelLog, IFatLinkType
+from .permissions import get_user_permissions
 from .providers import esi
 from .tasks import get_or_create_char, process_fats
 from .utils import LoggerAddTag
 
-import random
-
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -38,6 +44,12 @@ logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 # Create your views here.
 @login_required()
 def imicusfat_view(request):
+    """
+    imicusfat_view
+    :param request:
+    :return:
+    """
+
     msg = None
 
     if "msg" in request.session:
@@ -63,7 +75,15 @@ def imicusfat_view(request):
 
     fatlinks = IFatLink.objects.order_by("ifattime").reverse()[:10]
 
-    context = {"fats": fats, "links": fatlinks, "msg": msg}
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
+    context = {
+        "fats": fats,
+        "links": fatlinks,
+        "msg": msg,
+        "permissions": permissions,
+    }
 
     logger.info("Module called by %s", request.user)
 
@@ -72,6 +92,13 @@ def imicusfat_view(request):
 
 @login_required()
 def stats(request, year=None):
+    """
+    statistics main view
+    :param request:
+    :param year:
+    :return:
+    """
+
     if year is None:
         year = datetime.now().year
 
@@ -120,11 +147,15 @@ def stats(request, year=None):
         char_l.append(char.character.character_id)
         months.append(char_l)
 
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
     context = {
         "data": data,
         "charstats": months,
         "year": year,
         "current_year": datetime.now().year,
+        "permissions": permissions,
     }
 
     logger.info("Statistics overview called by %s", request.user)
@@ -134,6 +165,15 @@ def stats(request, year=None):
 
 @login_required()
 def stats_char(request, charid, month=None, year=None):
+    """
+    character statistics view
+    :param request:
+    :param charid:
+    :param month:
+    :param year:
+    :return:
+    """
+
     character = EveCharacter.objects.get(character_id=charid)
     valid = [
         char.character for char in CharacterOwnership.objects.filter(user=request.user)
@@ -200,6 +240,9 @@ def stats_char(request, charid, month=None, year=None):
         ],
     ]
 
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
     context = {
         "character": character,
         "month": month,
@@ -213,6 +256,7 @@ def stats_char(request, charid, month=None, year=None):
         "data_ship_type": data_ship_type,
         "data_time": data_time,
         "fats": fats,
+        "permissions": permissions,
     }
 
     logger.info("Character statistics called by %s", request.user)
@@ -223,6 +267,18 @@ def stats_char(request, charid, month=None, year=None):
 @login_required()
 @permissions_required(("imicusfat.stats_corp_own", "imicusfat.stats_corp_other"))
 def stats_corp(request, corpid, month=None, year=None):
+    """
+    corp statistics view
+    :param request:
+    :param corpid:
+    :param month:
+    :param year:
+    :return:
+    """
+
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
     # Check character has permission to view other corp stats
     if int(request.user.profile.main_character.corporation_id) != int(corpid):
         if not request.user.has_perm("imicusfat.stats_corp_other"):
@@ -256,6 +312,7 @@ def stats_corp(request, corpid, month=None, year=None):
             "corpid": corpid,
             "year": year,
             "type": 0,
+            "permissions": permissions,
         }
 
         return render(request, "imicusfat/date_select.html", context)
@@ -367,6 +424,7 @@ def stats_corp(request, corpid, month=None, year=None):
         "data_time": data_time,
         "data_weekday": data_weekday,
         "chars": chars,
+        "permissions": permissions,
     }
 
     logger.info("Corporation statistics for %s called by %s", corp_name, request.user)
@@ -377,6 +435,18 @@ def stats_corp(request, corpid, month=None, year=None):
 @login_required()
 @permission_required("imicusfat.stats_corp_other")
 def stats_alliance(request, allianceid, month=None, year=None):
+    """
+    fatlinks view
+    :param request:
+    :param allianceid:
+    :param month:
+    :param year:
+    :return:
+    """
+
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
     if allianceid == "000":
         allianceid = None
 
@@ -407,6 +477,7 @@ def stats_alliance(request, allianceid, month=None, year=None):
             "corpid": allianceid,
             "year": year,
             "type": 1,
+            "permissions": permissions,
         }
 
         return render(request, "imicusfat/date_select.html", context)
@@ -574,6 +645,7 @@ def stats_alliance(request, allianceid, month=None, year=None):
         "data_weekday": data_weekday,
         "corps": corps,
         "data_ship_type": data_ship_type,
+        "permissions": permissions,
     }
 
     logger.info("Alliance statistics for %s called by %s", alliance_name, request.user)
@@ -583,6 +655,12 @@ def stats_alliance(request, allianceid, month=None, year=None):
 
 @login_required()
 def links(request):
+    """
+    fatlinks view
+    :param request:
+    :return:
+    """
+
     msg = None
 
     if "msg" in request.session:
@@ -594,7 +672,10 @@ def links(request):
         .annotate(number_of_fats=Count("ifat", filter=Q(ifat__deleted_at__isnull=True)))
     )
 
-    context = {"links": fatlinks, "msg": msg}
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
+    context = {"links": fatlinks, "msg": msg, "permissions": permissions}
 
     logger.info("FAT link list called by %s", request.user)
 
@@ -604,14 +685,25 @@ def links(request):
 @login_required()
 @permissions_required(("imicusfat.manage_imicusfat", "imicusfat.add_ifatlink"))
 def link_add(request):
+    """
+    add fatlink view
+    :param request:
+    :return:
+    """
+
     msg = None
 
     if "msg" in request.session:
         msg = request.session.pop("msg")
 
-    link_types = IFatLinkType.objects.all().order_by("name")
+    link_types = IFatLinkType.objects.filter(
+        is_enabled=True,
+    ).order_by("name")
 
-    context = {"link_types": link_types, "msg": msg}
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
+    context = {"link_types": link_types, "msg": msg, "permissions": permissions}
 
     logger.info("Add FAT link view called by %s", request.user)
 
@@ -621,11 +713,18 @@ def link_add(request):
 @login_required()
 @permissions_required(("imicusfat.manage_imicusfat", "imicusfat.add_ifatlink"))
 def link_create_click(request):
+    """
+    create fatlink helper
+    :param request:
+    :return:
+    """
+
     if request.method == "POST":
         form = ClickFatForm(request.POST)
 
         if form.is_valid():
             fatlinkhash = get_random_string(length=30)
+
             link = IFatLink()
             link.fleet = form.cleaned_data["name"]
 
@@ -680,6 +779,14 @@ def link_create_click(request):
 @permissions_required(("imicusfat.manage_imicusfat", "imicusfat.add_ifatlink"))
 @token_required(scopes=["esi-fleets.read_fleet.v1"])
 def link_create_esi(request, token, hash):
+    """
+    create ESI link helper
+    :param request:
+    :param token:
+    :param hash:
+    :return:
+    """
+
     # Check if there is a fleet
     try:
         required_scopes = ["esi-fleets.read_fleet.v1"]
@@ -709,8 +816,6 @@ def link_create_esi(request, token, hash):
                 "You can create a clickable FAT link and share it, if you like.",
             ]
 
-            return redirect("imicusfat:link_edit", hash=hash)
-
             # since the FAT link has already been created, we need to remove it again
             link = IFatLink.objects.get(hash=hash)
             IFat.objects.filter(ifatlink_id=link.pk).delete()
@@ -719,6 +824,7 @@ def link_create_esi(request, token, hash):
             # return to "Add FAT Link" view
             return redirect("imicusfat:link_add")
     except Exception:
+        # Not in fleet
         request.session["msg"] = [
             "warning",
             "To use the ESI function, you neeed to be in fleet and you need to be the fleet boss! "
@@ -736,23 +842,36 @@ def link_create_esi(request, token, hash):
 
 @login_required()
 def create_esi_fat(request):
+    """
+    create ESI fat helper
+    :param request:
+    :return:
+    """
+
     form = FatLinkForm(request.POST)
     fat_link_hash = get_random_string(length=30)
 
     if form.is_valid():
         link = IFatLink(
-            fleet=form.cleaned_data["name"], creator=request.user, hash=fat_link_hash
+            fleet=form.cleaned_data["name_esi"],
+            creator=request.user,
+            hash=fat_link_hash,
         )
 
-        if form.cleaned_data["type"] is not None and form.cleaned_data["type"] != -1:
-            link.link_type = IFatLinkType.objects.get(id=form.cleaned_data["type"])
+        if (
+            form.cleaned_data["type_esi"] is not None
+            and form.cleaned_data["type_esi"] != -1
+        ):
+            link.link_type = IFatLinkType.objects.get(id=form.cleaned_data["type_esi"])
+
+        link.is_esilink = True
         link.save()
 
         return redirect("imicusfat:link_create_esi", hash=fat_link_hash)
     else:
         request.session["msg"] = [
             "danger",
-            ("Something went wrong when attempting to submit your" " ESI FAT Link."),
+            "Something went wrong when attempting to submit your ESI FAT Link.",
         ]
 
         return redirect("imicusfat:imicusfat_view")
@@ -763,6 +882,14 @@ def create_esi_fat(request):
     scopes=["esi-location.read_location.v1", "esi-location.read_ship_type.v1"]
 )
 def click_link(request, token, hash=None):
+    """
+    click fatlink helper
+    :param request:
+    :param token:
+    :param hash:
+    :return:
+    """
+
     if hash is None:
         request.session["msg"] = ["warning", "No FAT link hash provided."]
 
@@ -771,7 +898,7 @@ def click_link(request, token, hash=None):
     try:
         try:
             fleet = IFatLink.objects.get(hash=hash)
-        except Exception:
+        except IFatLink.DoesNotExist:
             request.session["msg"] = ["warning", "The hash provided is not valid."]
 
             return redirect("imicusfat:imicusfat_view")
@@ -787,6 +914,7 @@ def click_link(request, token, hash=None):
                     "contact your FC about having your FAT manually added."
                 ),
             ]
+
             return redirect("imicusfat:imicusfat_view")
 
         character = EveCharacter.objects.get(character_id=token.character_id)
@@ -883,6 +1011,16 @@ def click_link(request, token, hash=None):
     )
 )
 def edit_link(request, hash=None):
+    """
+    edit fatlink view
+    :param request:
+    :param hash:
+    :return:
+    """
+
+    # get users permissions
+    permissions = get_user_permissions(request.user)
+
     if hash is None:
         request.session["msg"] = ["warning", "No FAT Link hash provided."]
 
@@ -890,24 +1028,23 @@ def edit_link(request, hash=None):
 
     try:
         link = IFatLink.objects.get(hash=hash)
-    except Exception:
+    except IFatLink.DoesNotExist:
         request.session["msg"] = ["warning", "The hash provided is not valid."]
 
         return redirect("imicusfat:imicusfat_view")
 
     if request.method == "POST":
-        f1 = FatLinkForm(request.POST)
-        f3 = ManualFatForm(request.POST)
+        fatlink_edit_form = FatLinkEditForm(request.POST)
+        manual_fat_form = ManualFatForm(request.POST)
 
-        if f1.is_valid():
-            link.fleet = request.POST["fleet"]
+        if fatlink_edit_form.is_valid():
+            link.fleet = fatlink_edit_form.cleaned_data["fleet"]
             link.save()
             request.session["{}-task-code".format(hash)] = 1
-        elif f3.is_valid():
-            form = request.POST
-            character_name = form["character"]
-            system = form["system"]
-            shiptype = form["shiptype"]
+        elif manual_fat_form.is_valid():
+            character_name = manual_fat_form.cleaned_data["character"]
+            system = manual_fat_form.cleaned_data["system"]
+            shiptype = manual_fat_form.cleaned_data["shiptype"]
             creator = request.user
             character = get_or_create_char(name=character_name)
 
@@ -959,8 +1096,10 @@ def edit_link(request, hash=None):
         now = timezone.now() - timedelta(minutes=dur.duration)
 
         if now >= link.ifattime:
+            # link expired
             link_ongoing = False
-    except Exception:
+    except ClickIFatDuration.DoesNotExist:
+        # ESI link
         link_ongoing = False
 
     context = {
@@ -971,6 +1110,7 @@ def edit_link(request, hash=None):
         "fats": fats,
         "flatlist": flatlist,
         "link_ongoing": link_ongoing,
+        "permissions": permissions,
     }
 
     logger.info("FAT link %s edited by %s", hash, request.user)
@@ -981,6 +1121,13 @@ def edit_link(request, hash=None):
 @login_required()
 @permissions_required(("imicusfat.manage_imicusfat", "imicusfat.delete_ifatlink"))
 def del_link(request, hash=None):
+    """
+    delete fatlink helper
+    :param request:
+    :param hash:
+    :return:
+    """
+
     if hash is None:
         request.session["msg"] = ["warning", "No FAT Link hash provided."]
 
@@ -988,7 +1135,7 @@ def del_link(request, hash=None):
 
     try:
         link = IFatLink.objects.get(hash=hash)
-    except Exception:
+    except IFatLink.DoesNotExist:
         request.session["msg"] = [
             "danger",
             "The hash provided is either invalid or has been deleted.",
@@ -1017,9 +1164,17 @@ def del_link(request, hash=None):
 @login_required()
 @permissions_required(("imicusfat.manage_imicusfat", "imicusfat.delete_ifat"))
 def del_fat(request, hash, fat):
+    """
+    delete fat helper
+    :param request:
+    :param hash:
+    :param fat:
+    :return:
+    """
+
     try:
         link = IFatLink.objects.get(hash=hash)
-    except Exception:
+    except IFatLink.DoesNotExist:
         request.session["msg"] = [
             "danger",
             "The hash provided is either invalid or has been deleted.",
@@ -1029,7 +1184,7 @@ def del_fat(request, hash, fat):
 
     try:
         fat = IFat.objects.get(pk=fat, ifatlink_id=link.pk)
-    except Exception:
+    except IFat.DoesNotExist:
         request.session["msg"] = [
             "danger",
             "The hash and FAT ID do not match.",
